# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_algorithm.ipynb.

# %% ../nbs/01_algorithm.ipynb 2
from __future__ import annotations

# %% auto 0
__all__ = ['bar']

# %% ../nbs/01_algorithm.ipynb 5
def bar(): pass
