# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/',
                'doc_host': 'https://docs.gograph.org',
                'git_url': 'https://github.com/rossheat/gograph',
                'lib_path': 'gograph'},
  'syms': { 'gograph.algorithm': {'gograph.algorithm.bar': ('algorithm.html#bar', 'gograph/algorithm.py')},
            'gograph.core': {'gograph.core.foo': ('core.html#foo', 'gograph/core.py')},
            'gograph.graph': { 'gograph.graph.Graph': ('graph.html#graph', 'gograph/graph.py'),
                               'gograph.graph.Graph.__init__': ('graph.html#__init__', 'gograph/graph.py'),
                               'gograph.graph.Graph.n_vertices': ('graph.html#graph.n_vertices', 'gograph/graph.py'),
                               'gograph.graph.Graph.say_hello': ('graph.html#graph.say_hello', 'gograph/graph.py'),
                               'gograph.graph.print_hello': ('graph.html#print_hello', 'gograph/graph.py')}}}