# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_graph.ipynb.

# %% ../nbs/00_graph.ipynb 2
from __future__ import annotations
from fastcore.all import * 

# %% auto 0
__all__ = ['Graph', 'print_hello']

# %% ../nbs/00_graph.ipynb 6
class Graph: 
    "A graph."
    def __init__(self, 
                 vertices: list[str], # The vertices
                 edges: list[str] # The egdes
                ) -> None:
        self.vertices = vertices
        self.edges = edges

# %% ../nbs/00_graph.ipynb 7
@patch 
def n_vertices(self: Graph) -> int: 
    "Return number of verticles."
    return len(self.vertices)

# %% ../nbs/00_graph.ipynb 8
@patch
def say_hello(
    self: Graph, 
    to: str # The person to say hello to 
)-> str: 
    return f"Hello {to}"

# %% ../nbs/00_graph.ipynb 11
def print_hello(): 
    print("hello")
